==> sdk-3.0.0-sources.jar: com/kontakt/sdk/android/ble/service/Callbacks.java <==
package com.kontakt.sdk.android.ble.service;

import android.os.Messenger;
import com.kontakt.sdk.android.ble.configuration.scan.ScanContext;
import com.kontakt.sdk.android.ble.manager.listeners.InternalProximityListener;
import com.kontakt.sdk.android.common.util.SDKPreconditions;
import java.util.ArrayList;
import java.util.Collection;
import java.util.Collections;

final class Callbacks {

  private Callbacks() {
  }

  static BleScanCallback newCallback(final Configuration configuration) {
    SDKPreconditions.checkNotNull(configuration, "Configuration cannot be null");

    return new MonitorCallback(configuration) {
    };
  }

  static final class Configuration {

    final ScanContext scanContext;

    final Collection<InternalProximityListener> proximityListeners;

    final Messenger messenger;

    private Configuration(final ScanContext scanContext, Collection<InternalProximityListener> proximityListeners,
        final Messenger messenger) {
      this.scanContext = scanContext;
      this.proximityListeners = Collections.unmodifiableCollection(proximityListeners);
      this.messenger = messenger;
    }

    static class Builder {
      private ScanContext scanContext;
      private Messenger messenger;
      private final Collection<InternalProximityListener> proximityListeners = new ArrayList<InternalProximityListener>();

      Builder() {

      }

      Builder setScanContext(final ScanContext scanContext) {
        this.scanContext = scanContext;
        return this;
      }

      Builder setServiceMessenger(final Messenger messenger) {
        this.messenger = messenger;
        return this;
      }

      Builder addMonitoringListeners(Collection<InternalProximityListener> proximityListeners) {
        this.proximityListeners.addAll(proximityListeners);
        return this;
      }

      Configuration build() {
        return new Configuration(scanContext, proximityListeners, messenger);
      }
    }
  }
}

==> sdk-3.1.0-sources.jar: com/kontakt/sdk/android/ble/service/Callbacks.java <==
package com.kontakt.sdk.android.ble.service;

import android.os.Messenger;
import com.kontakt.sdk.android.ble.configuration.scan.ScanContext;
import com.kontakt.sdk.android.ble.manager.listeners.InternalProximityListener;
import com.kontakt.sdk.android.common.util.SDKPreconditions;
import java.util.ArrayList;
import java.util.Collection;
import java.util.Collections;

final class Callbacks {

  private Callbacks() {
  }

  static BleScanCallback newCallback(final Configuration configuration) {
    SDKPreconditions.checkNotNull(configuration, "Configuration cannot be null");

    return new MonitorCallback(configuration) {
    };
  }

  static final class Configuration {

    final ScanContext scanContext;

    final Collection<InternalProximityListener> proximityListeners;

    final Messenger messenger;

    private Configuration(final ScanContext scanContext, Collection<InternalProximityListener> proximityListeners,
        final Messenger messenger) {
      this.scanContext = scanContext;
      this.proximityListeners = Collections.unmodifiableCollection(proximityListeners);
      this.messenger = messenger;
    }

    static class Builder {
      private ScanContext scanContext;
      private Messenger messenger;
      private final Collection<InternalProximityListener> proximityListeners = new ArrayList<>();

      Builder() {

      }

      Builder setScanContext(final ScanContext scanContext) {
        this.scanContext = scanContext;
        return this;
      }

      Builder setServiceMessenger(final Messenger messenger) {
        this.messenger = messenger;
        return this;
      }

      Builder addMonitoringListeners(Collection<InternalProximityListener> proximityListeners) {
        this.proximityListeners.addAll(proximityListeners);
        return this;
      }

      Configuration build() {
        return new Configuration(scanContext, proximityListeners, messenger);
      }
    }
  }
}
